# README
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/EchoBetaGlass/pyrvea/master)

The python version reference vector guided evolutionary algorithm.

Currently supported: Multi-objective minimization with visualization and interaction support. Preference is accepted as a reference point.

To test the code, open the [binder link](https://mybinder.org/v2/gh/EchoBetaGlass/pyrvea/master) and read example.ipynb.

Read the documentation [here](https://pyrvea.readthedocs.io/en/latest/)

### Requirements:
* Python 3.6 or up
* [Poetry dependency manager](https://github.com/sdispater/poetry): Only for developers

### Installation process for normal users:
* Run: `pip install pyrvea`

### Installation process for developers:
* Download and extract the code
* Create a new virtual environment for the project
* If you want to take part in the development process, run `poetry install` instead.

## See the details of RVEA in the following paper

R. Cheng, Y. Jin, M. Olhofer and B. Sendhoff,
A Reference Vector Guided Evolutionary Algorithm for Many-objective
Optimization, IEEE Transactions on Evolutionary Computation, 2016

The source code of pyrvea is implemented by Bhupinder Saini

If you have any questions about the code, please contact:

Bhupinder Saini: bhupinder.s.saini@jyu.fi\
Project researcher at University of Jyväskylä.